@@ -3,7 +3,7 @@ from __future__ import annotations
 from mkdocs.structure.nav import Section
 from mkdocs.structure.pages import Page
 
-__version__ = "0.3.8"
+__version__ = "0.3.9"
 __all__ = ["SectionPage"]
 
 
@@ -13,7 +13,7 @@ class SectionPage(Section, Page):  # type: ignore[misc]
         Section.__init__(self, title=title, children=children)
         self.is_section = self.is_page = True
 
-    active = Page.active  # type: ignore
+    active = Page.active  # type: ignore[assignment]
 
     def __repr__(self):
         result = Page.__repr__(self)
