@@ -1,7 +1,6 @@
 import functools
 import http.server
 import logging
-import sys
 import threading
 
 import pytest
@@ -20,8 +19,6 @@ def cap_log():
 
 @pytest.fixture(scope="session")
 def http_server(tmp_path_factory):
-    if sys.version_info < (3, 7):
-        pytest.skip("limitation of http.server", allow_module_level=True)
     directory = tmp_path_factory.mktemp("http_server")
     httpd = http.server.HTTPServer(
         ("localhost", 0),
